//
//  ParcelDetailController.swift
//  RWPS
//
//  Created by Mic Pringle on 05/12/2014.
//  Copyright (c) 2014 Razeware LLC. All rights reserved.
//

import WatchKit
import Foundation

class ParcelDetailController: WKInterfaceController {
  
  @IBOutlet weak var itemNameLabel: WKInterfaceLabel!
  @IBOutlet weak var daysRemainingLabel: WKInterfaceLabel!
  @IBOutlet weak var daysLabel: WKInterfaceLabel!
  @IBOutlet weak var statusLabel: WKInterfaceLabel!
  @IBOutlet weak var deliveredByLabel: WKInterfaceLabel!
  @IBOutlet weak var locationLabel: WKInterfaceLabel!
  @IBOutlet weak var map: WKInterfaceMap!
  
  var parcel: Parcel!
  
  lazy var deliveredByDateFormatter: NSDateFormatter = {
    let dateFormatter = NSDateFormatter()
    dateFormatter.dateFormat = "d MMMM"
    return dateFormatter
    }()
    
  override func awakeWithContext(context: AnyObject!) {
    super.awakeWithContext(context)
    if let parcel = context as? Parcel {
      self.parcel = parcel
    }
  }
  
  override func willActivate() {
    super.willActivate()
    
    if parcel == nil {
      return
    }
    
    let numberOfDaysRemaining = parcel.daysRemainingBeforeDelivery()
    itemNameLabel.setText(parcel.itemName)
    daysRemainingLabel.setText("\(numberOfDaysRemaining)")
    daysLabel.setText(numberOfDaysRemaining == 1 ? "DAY" : "DAYS")
    statusLabel.setText(parcel.status)
    deliveredByLabel.setText(deliveredByDateFormatter.stringFromDate(parcel.deliveryDate))
    locationLabel.setText(parcel.location)
    
    map.setRegion(parcel.locationCoordinateRegion)
    map.addAnnotation(parcel.locationCoordinate, withImageNamed: "DeliveryVan", centerOffset: CGPointZero)
  }
  
  @IBAction func addToCalendar() {
    WKInterfaceController.openParentApplication(["orderNo": parcel.orderNo], reply: {(reply, error) -> Void in
      if let eventCreated = reply["eventCreated"] as? NSNumber {
        let messageText = eventCreated.boolValue ? "The delivery was added to your calendar" : "Failed to add the delivery to your calendar"
        self.presentControllerWithName("addToCalendarResponse", context: messageText)
      }
    })
  }
  
  
}