//
//  ParcelListController.swift
//  RWPS WatchKit Extension
//
//  Created by Mic Pringle on 05/12/2014.
//  Copyright (c) 2014 Razeware LLC. All rights reserved.
//

import WatchKit
import Foundation

class ParcelListController: WKInterfaceController {
  
  @IBOutlet weak var table: WKInterfaceTable!
  @IBOutlet weak var noParcelsLabel: WKInterfaceLabel!
  
  var parcels = [Parcel]()
  var coreDataStack: CoreDataStack!
  
  lazy var deliveryDateFormatter: NSDateFormatter = {
    let dateFormatter = NSDateFormatter()
    dateFormatter.dateFormat = "d MMMM"
    return dateFormatter
  }()

  override init() {
    super.init()
    coreDataStack = CoreDataStack()
  }
    
  override func handleUserActivity(userInfo: [NSObject : AnyObject]!) {
    if let orderNo = userInfo["orderNo"] as? String {
      if let parcel = coreDataStack.parcelWithOrderNo(orderNo) {
        pushControllerWithName("parcelDetailController", context: parcel)
      }
    }
  }
  
  override func willActivate() {
    super.willActivate()
    
    parcels = coreDataStack.allParcels()
    
    table.setHidden(parcels.count == 0)
    noParcelsLabel.setHidden(parcels.count > 0)
    
    table.setNumberOfRows(parcels.count, withRowType: "ParcelRowType")
    for (index, parcel) in enumerate(parcels) {
      if let row = table.rowControllerAtIndex(index) as? ParcelRowController {
        row.itemNameLabel.setText(parcel.itemName)
        row.deliveryDateLabel.setText(deliveryDateFormatter.stringFromDate(parcel.deliveryDate))
      }
    }

  }
  
  override func contextForSegueWithIdentifier(segueIdentifier: String, inTable table: WKInterfaceTable, rowIndex: Int) -> AnyObject? {
    return parcels[rowIndex]
  }
  
}
