//
//  EventManager.swift
//  RWPS
//
//  Created by Mic Pringle on 15/12/2014.
//  Copyright (c) 2014 Razeware LLC. All rights reserved.
//

import Foundation
import EventKit

class EventManager {
  
  private lazy var dateFormatter: NSDateFormatter = {
    let formatter = NSDateFormatter()
    formatter.dateFormat = "dd-MM-yy H:mm"
    return formatter
  }()
  
  func addEventForParcel(parcel: Parcel) -> Bool {
    let store = EKEventStore()
    let event = EKEvent(eventStore: store)
    event.allDay = true
    event.calendar = store.defaultCalendarForNewEvents
    event.startDate = parcel.deliveryDate
    event.endDate = parcel.deliveryDate
    event.title = "Delivery of \(parcel.itemName) from \(parcel.supplierName)"
    var error: NSError? = nil
    store.saveEvent(event, span: EKSpanThisEvent, error: &error)
    return (error == nil)
  }
  
  func addEventForNotification(payload: NSDictionary) -> Bool {
    let store = EKEventStore()
    let event = EKEvent(eventStore: store)
    let startDate = dateFormatter.dateFromString(payload["startDate"] as String)
    let endDate = dateFormatter.dateFromString(payload["endDate"] as String)
    let itemName = payload["itemName"] as String
    let supplierName = payload["supplierName"] as String
    event.allDay = false
    event.calendar = store.defaultCalendarForNewEvents
    event.startDate = startDate
    event.endDate = endDate
    event.title = "Delivery of \(itemName) from \(supplierName)"
    var error: NSError? = nil
    store.saveEvent(event, span: EKSpanThisEvent, error: &error)
    return (error == nil)
  }
  
  func isAuthorised() -> Bool {
    return EKEventStore.authorizationStatusForEntityType(EKEntityTypeEvent) == EKAuthorizationStatus.Authorized
  }
  
  func requestAuthorisation() {
    let store = EKEventStore()
    store.requestAccessToEntityType(EKEntityTypeEvent, completion: { _ = $0 })
  }
  
  func shouldRequestAuthorisation() -> Bool {
    return EKEventStore.authorizationStatusForEntityType(EKEntityTypeEvent) == EKAuthorizationStatus.NotDetermined
  }
  
}
